/*****************************************************************************/
/*
                                  file.h
*/
/*****************************************************************************/

#ifndef FILE_H_LOADED
#define FILE_H_LOADED 1

#include <atrdef.h>
#include <fibdef.h>

#include "wasd.h"

/**************/
/* structures */
/**************/

/* used by the file.c and dir.c modules */
struct FileRecordAttributes
{
   unsigned char  RecordType;
   unsigned char  OfNoInterest1;
   unsigned short  RecordSize;
   unsigned short  AllocatedVbnHi;
   unsigned short  AllocatedVbnLo;
   unsigned short  EndOfFileVbnHi;
   unsigned short  EndOfFileVbnLo;
   unsigned short  FirstFreeByte;
   unsigned char   OfNoInterest3 [18];
};

/* used by the file.c and dir.c modules */
struct FileAcpStruct
{
   unsigned short  Channel,
                   AtrFpro;
   unsigned long  AtrUic;
   unsigned long  CdtBinTime [2],
                  RdtBinTime [2];
   struct FileRecordAttributes  RecAttr;
   struct fibdef  FileFib;
   struct atrdef  FileAtr [6];
   struct dsc$descriptor  FileFibAcpDsc,
                          FileNameAcpDsc;
   struct AnIOsb  AcpIOsb;
};

struct FileTaskStruct
{
   boolean  /* SYSUAF authenticated user has been checked to have access */
            AuthVmsUserHasAccess,
            /* caching of this file is allowed */
            CacheAllowed,
            /* some parse structures may need freeing */
            ParseInUse,
            /* to be read record-by-record, or by block I/O (from ACP QIO) */
            RecordIO,
            /* when true a file's contents are enclosed in <PRE></PRE> tags */
            PreTagFileContents,
            /* when a file's contents have been <PRE>ed, end with </PRE> tag */
            PreTagEndFileContents,
            /* when true HTML-forbidden characters are escaped */
            EscapeHtml;

   int  /* size of buffer for escaping HTML */
        EscapeHtmlSize,
        /* */
        FileNameLength,
        /* buffer for most recent task status */
        TaskStatusBuffer;

   unsigned short /* first free byte in end-of-file VBN */
                  FirstFreeByte;

   unsigned long  /* virtual block number of end-of-file */
                  EndOfFileVbn,
                  /* (from ACP QIO) */
                  SizeInBytes;

   unsigned long  /* 64 bit VMS time when file was modified (from ACP QIO) */
                  ModifiedBinaryTime [2];

   char  /* */
         ExpandedFileName [256],
         /* */
         FileName [256];

   unsigned char  /* pointer to MIME content-type */
                  *ContentTypePtr,
                  /* pointer to buffer used to escape HTML-forbidden chars */
                  *EscapeHtmlPtr;

   /* structure for ACP info */
   struct FileAcpStruct  FileAcpData;

   /* RMS structures */
   struct FAB  FileFab;
   struct RAB  FileRab;
   struct NAM  FileNam;

   /* pointers to function, used for specifying open-error and next task */
   void (*NextTaskFunction)(struct RequestStruct*);
   void (*FileOpenErrorFunction)(struct RequestStruct*);
};

/***********************/
/* function prototypes */
/***********************/

FileAcpInfoAst (struct RequestStruct*); 
FileBegin (struct RequestStruct*, void*, void*, char*, char*,
           boolean, boolean, boolean);
FileClosed (struct FAB*); 
FileConnectAst (struct RAB*); 
FileEnd (struct RequestStruct*);
FileEmptyBuffer (struct RequestStruct*);
FileFlushBuffer (struct RequestStruct*, void*);
FileFlushBufferEscapeHtml (struct RequestStruct*, void*);
FileHttpHeader (struct RequestStruct*, int, char*, int);
FileNextBlocks (struct RequestStruct*);
FileNextBlocksAst (struct RAB*); 
FileNextRecord (struct RequestStruct*);
FileNextRecordAst (struct RAB*); 
FileOpen (struct FileTaskStruct*); 
FileOpenAst (struct FAB*); 
FileParseAst (struct FAB*); 
FileAcpInfo (struct RequestStruct*);

#endif /* FILE_H_LOADED */

/*****************************************************************************/
